package pro.skywalking.verify;

import com.alibaba.fastjson2.JSON;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import ma.glasnost.orika.MapperFacade;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.ExitCodeGenerator;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.ApplicationContext;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.web.context.WebApplicationContext;
import pro.skywalking.constants.PlatformConstant;
import pro.skywalking.utils.CheckParam;
import pro.skywalking.utils.HttpTookit;
import pro.skywalking.utils.MacUtil;
import pro.skywalking.verify.AccessRecordReq;
import pro.skywalking.verify.PlatformVerifyResp;

@Service("skyWalkingService")
public class SkyWalkingService {

   private static final Logger log = LoggerFactory.getLogger(SkyWalkingService.class);
   @Resource
   private ApplicationContext context;
   @Resource
   private WebApplicationContext applicationContext;
   @Resource
   private MapperFacade mapperFacade;
   private static String sendUrl = "https://skywalking.pro/skywalking-platform-api/api/v1/accessRecord/verifyAccess";
   private String actData = "系统启动";
   private String EMPTY_VALUE = "暂无";


   public String mainName() {
      Map annotatedBeans = this.context.getBeansWithAnnotation(SpringBootApplication.class);
      return annotatedBeans.isEmpty()?null:annotatedBeans.values().toArray()[0].getClass().getName();
   }

   public static void main(String[] args) {
      String macAddress = null;

      try {
         macAddress = MacUtil.getOneMac();
      } catch (Exception var3) {
         var3.printStackTrace();
      }

      System.out.println(macAddress);
   }

   public AccessRecordReq setAccRecord(AccessRecordReq record) {
      if(CheckParam.isNull(record)) {
         record = new AccessRecordReq();
      }

      String macAddress = null;
      InetAddress addr = null;

      try {
         macAddress = MacUtil.getOneMac();
         addr = InetAddress.getLocalHost();
      } catch (UnknownHostException var7) {
         if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
            log.error(">>>>>>>setAccRecord出现异常,{},{}<<<<<<<<<", var7.getMessage(), var7);
         }

         return this.setEmptyAccessValue(new AccessRecordReq());
      }

      String applicationName = this.mainName();
      String hostName = addr.getHostName();
      String hostAddress = CheckParam.isNull(record.getIpAddress())?addr.getHostAddress():record.getIpAddress();
      record.setHostName(CheckParam.isNull(hostName)?this.EMPTY_VALUE:hostName);
      record.setMacAddress(CheckParam.isNull(macAddress)?this.EMPTY_VALUE:macAddress);
      record.setIpAddress(CheckParam.isNull(hostAddress)?this.EMPTY_VALUE:hostAddress);
      record.setPlatformName(CheckParam.isNull(applicationName)?this.EMPTY_VALUE:applicationName);
      record.setActData(CheckParam.isNull(record.getActData())?this.EMPTY_VALUE:record.getActData());
      this.setEmptyAccessValue(record);
      if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
         log.info("record:{}", JSON.toJSONString(record));
      }

      return record;
   }

   private AccessRecordReq setEmptyAccessValue(AccessRecordReq record) {
      if(CheckParam.isNull(record)) {
         record = new AccessRecordReq();
      }

      String macAddress = record.getMacAddress();
      String applicationName = this.mainName();
      String hostName = record.getHostName();
      String hostAddress = record.getIpAddress();
      String actData = record.getActData();
      record.setHostName(CheckParam.isNull(hostName)?this.EMPTY_VALUE:hostName);
      record.setMacAddress(CheckParam.isNull(macAddress)?this.EMPTY_VALUE:macAddress);
      record.setIpAddress(CheckParam.isNull(hostAddress)?this.EMPTY_VALUE:hostAddress);
      record.setPlatformName(CheckParam.isNull(applicationName)?this.EMPTY_VALUE:applicationName);
      record.setActData(CheckParam.isNull(actData)?this.EMPTY_VALUE:actData);
      return record;
   }

   @PostConstruct
   public void sendDataBeforeStart() {
      if(PlatformConstant.NEED_VERIFY.booleanValue()) {
         if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
            log.info(">>>>>>>sendDataBeforeStart开始<<<<<<<<<");
         }

         AccessRecordReq record = this.setAccRecord(new AccessRecordReq());
         HashMap paramHashMap = (HashMap)JSON.parseObject(JSON.toJSONString(record), HashMap.class);

         try {
            if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
               log.info("paramHashMap:{}", JSON.toJSONString(paramHashMap));
            }

            String e = HttpTookit.postBodyRequest(sendUrl, new HashMap(), paramHashMap, new HashMap());
            if(CheckParam.isNull(e)) {
               if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
                  log.info(">>>>>> sendDataBeforeStart:异常埋点1 <<<<<<<<<");
               }

               this.shutdownNow();
            }

            PlatformVerifyResp platformVerifyResp = (PlatformVerifyResp)JSON.parseObject(e, PlatformVerifyResp.class);
            if(!platformVerifyResp.getVerify().booleanValue()) {
               if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
                  log.info(">>>>>> sendDataBeforeStart:异常埋点2 <<<<<<<<<");
               }

               this.shutdownNow();
            }
         } catch (Exception var5) {
            if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
               log.info(">>>>>> sendDataBeforeStart:异常埋点3 <<<<<<<<<");
               log.error(">>>>>>>sendDataBeforeStart出现异常,{},{}<<<<<<<<<", var5.getMessage(), var5);
            }

            this.shutdownNow();
         }

      }
   }

   @Async("threadPoolTaskExecutor")
   public void sendDataByActName(AccessRecordReq record) {
      if(PlatformConstant.NEED_VERIFY.booleanValue()) {
         AccessRecordReq recordData = this.setAccRecord(record);
         HashMap paramHashMap = (HashMap)JSON.parseObject(JSON.toJSONString(recordData), HashMap.class);

         try {
            if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
               log.info("paramHashMap:{}", JSON.toJSONString(paramHashMap));
            }

            String e = HttpTookit.postBodyRequest(sendUrl, new HashMap(), paramHashMap, new HashMap());
            if(CheckParam.isNull(e)) {
               if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
                  log.info(">>>>>> sendDataByActName:异常埋点1 <<<<<<<<<");
               }

               return;
            }

            PlatformVerifyResp platformVerifyResp = (PlatformVerifyResp)JSON.parseObject(e, PlatformVerifyResp.class);
            if(!platformVerifyResp.getVerify().booleanValue()) {
               if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
                  log.info(">>>>>> sendDataByActName:异常埋点2 <<<<<<<<<");
               }

               this.shutdownNow();
            }
         } catch (Exception var6) {
            if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
               log.info(">>>>>> sendDataByActName:异常埋点3 <<<<<<<<<");
               log.error(">>>>>>>sendDataBeforeStart出现异常,{},{}<<<<<<<<<", var6.getMessage(), var6);
            }

            this.shutdownNow();
         }

      }
   }

   public void shutdownNow() {
      if(PlatformConstant.NEED_PRINT_ACCESS_LOG.booleanValue()) {
         log.info(">>>>>>shutdownNow:执行关闭应用<<<<<<<");
      }

      System.exit(SpringApplication.exit(this.applicationContext, new ExitCodeGenerator[0]));
   }

}
